@@ -1,7 +1,7 @@
 from .core.ldict_ import Ldict as ldict
 from .empty import Empty
 from .parameter.functionspace import FunctionSpace
-from .parameter.let import Let as let
+from .parameter.let import lLet as let
 
 empty = Empty()
 """The empty object is used to induce a ldict from a dict"""
